@@ -3,7 +3,7 @@
    :platform: Any
    :synopsis: A Python module for working with weighted randomness.
 
-.. moduleauthor:: Waawal <waawal@boom.ws>
+.. moduleauthor:: Daniel Waardal <waawal@boom.ws>
 
 
 """
@@ -18,11 +18,11 @@ def choice(data):
        (based on inplace algorithm)
 
     Args:
-       data (Mapping or sequence of pairs):  (returnable, weight)
+       data (Mapping or sequence of pairs) in the form of:  (returnable, weight)
 
     Returns:
-       For Mappings: A key
-       For sequences of pairs: [0] of a pair.
+      For a mapping: A key of the passed in mapping.
+      For a sequence of pairs: [0] (the first position) of a pair.
 
     Usecase:
 
